package at.ac.uibk.gitsearch.config;

import java.util.List;

import org.springframework.boot.context.properties.ConfigurationProperties;

/**
 * Properties specific to Gitsearch.
 * <p>
 * Properties are configured in the {@code application.yml} file.
 * See {@link io.github.jhipster.config.JHipsterProperties} for a good example.
 */
@ConfigurationProperties(prefix = "application", ignoreUnknownFields = false)
public class ApplicationProperties {

    private Search search;

    private GitLab gitLab;
    
    private String registeredConnectorsCallBackURL;
    
    private String installationName;

	private String oerLink;
    
	private DeploymentInfo deploymentInfo;
    
    private List<RegisteredConnector>  registeredConnectorss;

    public static class RegisteredConnector {
    	private String url;
    	private String accessToken;
		/**
		 * @return the url
		 */
		public String getUrl() {
			return url;
		}
		/**
		 * @param url the url to set
		 */
		public void setUrl(String url) {
			this.url = url;
		}
		/**
		 * @return the accessToken
		 */
		public String getAccessToken() {
			return accessToken;
		}
		/**
		 * @param accessToken the accessToken to set
		 */
		public void setAccessToken(String accessToken) {
			this.accessToken = accessToken;
		}
		@Override
		public String toString() {
			String anonymizedAccessToken = accessToken;
			if (accessToken!=null && accessToken.length() > 3) {
				anonymizedAccessToken = accessToken.substring(3) + "...";
			}
			return "RegisteredConnector [url=" + url + ", accessToken=" + anonymizedAccessToken + "]";
		}
    	
		
    	
    }
    /**
     * a list of URLs of Connectors to be registered.
	 * @return the registeredConnectors
	 */
	public List<RegisteredConnector> getRegisteredConnectors() {
		return registeredConnectorss;
	}

	public String getOerLink() {
		return oerLink;
	}

	public void setOerLink(String oerLink) {
		this.oerLink = oerLink;
	}

	/**
	 * @param registeredConnectors the registeredConnectors to set
	 */
	public void setRegisteredConnectors(List<RegisteredConnector>  registeredConnectors) {
		this.registeredConnectorss = registeredConnectors;
	}

	public Search getSearch() {
        return search;
    }

    public void setSearch(Search search) {
        this.search = search;
    }

	public GitLab getGitLab() {
        return gitLab;
    }

    public void setGitLab(GitLab gitLab) {
        this.gitLab = gitLab;
    }

    /**
	 * @return the registeredConnectorsCallBackURL
	 */
	public String getRegisteredConnectorsCallBackURL() {
		return registeredConnectorsCallBackURL;
	}

	/**
	 * @param registeredConnectorsCallBackURL the registeredConnectorsCallBackURL to set
	 */
	public void setRegisteredConnectorsCallBackURL(String registeredConnectorsCallBackURL) {
		this.registeredConnectorsCallBackURL = registeredConnectorsCallBackURL;
	}

	/**
	 * @return the name of this installation
	 */
	public String getInstallationName() {
		return installationName;
	}

	/**
	 * @param installationName the installationName to set
	 */
	public void setInstallationName(String installationName) {
		this.installationName = installationName;
	}

	/**
	 * @return the deploymentInfo
	 */
	public DeploymentInfo getDeploymentInfo() {
		return deploymentInfo;
	}

	/**
	 * @param deploymentInfo the deploymentInfo to set
	 */
	public void setDeploymentInfo(DeploymentInfo deploymentInfo) {
		this.deploymentInfo = deploymentInfo;
	}

	public static class Search {

        private String highlightPre;
        private String highlightPost;

        public String getHighlightPre() {
            return highlightPre;
        }

        public void setHighlightPre(String highlightPre) {
            this.highlightPre = highlightPre;
        }

        public String getHighlightPost() {
            return highlightPost;
        }

        public void setHighlightPost(String highlightPost) {
            this.highlightPost = highlightPost;
        }
    }

    public static class GitLab {
        private String url;
        private String guestAccessToken;
        private String adminAccessToken;
        
        public String getUrl() {
            return url;
        }

        public void setUrl(String url) {
            this.url = url;
        }

		/**
		 * @return the guestAccessToken
		 */
		public String getGuestAccessToken() {
			return guestAccessToken;
		}

		/**
		 * @param guestAccessToken the guestAccessToken to set
		 */
		public void setGuestAccessToken(String guestAccessToken) {
			this.guestAccessToken = guestAccessToken;
		}

		/**
		 * @return the adminAccessToken
		 */
		public String getAdminAccessToken() {
			return adminAccessToken;
		}

		/**
		 * @param adminAccessToken the adminAccessToken to set
		 */
		public void setAdminAccessToken(String adminAccessToken) {
			this.adminAccessToken = adminAccessToken;
		}
        
    }
    
    public static class DeploymentInfo {
    	@Override
		public String toString() {
			return "DeploymentInfo [" + commitId + "/" + branch + "]";
		}
		private String commitId = "---";
    	private String branch = "---";
    	private String deploymentDate = ""; 
		/**
		 * @return the commitId
		 */
		public String getCommitId() {
			return commitId;
		}
		/**
		 * @param commitId the commitId to set
		 */
		public void setCommitId(String commitId) {
			this.commitId = commitId;
		}
		/**
		 * @return the branch
		 */
		public String getBranch() {
			return branch;
		}
		/**
		 * @param branch the branch to set
		 */
		public void setBranch(String branch) {
			this.branch = branch;
		}
		/**
		 * @return the deploymentDate
		 */
		public String getDeploymentDate() {
			return deploymentDate;
		}
		/**
		 * @param deploymentDate the deploymentDate to set
		 */
		public void setDeploymentDate(String deploymentDate) {
			this.deploymentDate = deploymentDate;
		}
    }
}
