import { HttpClient, HttpParams, HttpXhrBackend } from '@angular/common/http';
import { NgModule } from '@angular/core';
import { ApplicationConfigService } from 'app/core/config/application-config.service';
import { PagesMarkDownViewerComponent } from 'app/editorialPages/markDownViewer/markDownViewer.component';
import { SharedLibsModule } from '../shared/shared-libs.module';
import { MarkdownModule, MarkedOptions, MarkedRenderer } from 'ngx-markdown';
import { Observable } from 'rxjs';

import { PagesComponent } from './pages.component';

export class MyRenderer extends MarkedRenderer {
  public attachmentResourceURL = this.applicationConfigService.getEndpointFor('api/pages/attachment');
  
  constructor(private applicationConfigService: ApplicationConfigService) {
    super();
    }


  image(href: string | null, title: string | null, text: string): string {
    const analyzedHref = href;
    if (href && href.startsWith('uploads')) {
      const http = new HttpClient(new HttpXhrBackend({ build: () => new XMLHttpRequest() }));
      const resp = this.getAttachmentURL(href, http);
      resp.subscribe(
        url => {
          const srcQuery = '[src="' + href + '"]';
          const elem = window.document.querySelectorAll(srcQuery);
          if (elem) elem.forEach(node => node.setAttribute('src', url));
        },
        e => {
          alert(e);
        }
      );

      const out = '<image src="' + href + '" alt="image"/>'; // warning: the output goes through a HTML
      // Sanitizer, which eliminates
      // various attributes: see e.g.
      // https://stackoverflow.com/questions/57400432/angular-how-to-retain-html-id-attribute-when-sanitized
      return out;
    }
    return super.image(analyzedHref, title, text);
  }

  getAttachmentURL(path: string, http: HttpClient): Observable<string> {
    const parameters = new HttpParams().set('path', path);
    return http.get(this.attachmentResourceURL, { params: parameters, responseType: 'text' as 'text' });
  }
}

// function that returns `MarkedOptions` with renderer override
export function markedOptionsFactory(): MarkedOptions {
  const myRenderer = new MyRenderer();

  return {
    renderer: myRenderer,
    gfm: true,
    baseUrl: '/pages/',
    breaks: false,
    pedantic: false,
    smartLists: true,
    smartypants: true,
    xhtml: true,
  };
}

@NgModule({
  imports: [
    SharedLibsModule,
    MarkdownModule.forRoot({
      markedOptions: {
        provide: MarkedOptions,
        useFactory: markedOptionsFactory,
      },
      //  sanitize: SecurityContext.NONE
    }),
  ],
  declarations: [PagesMarkDownViewerComponent, PagesComponent],
  exports: [PagesMarkDownViewerComponent],
})
export class PagesModule {}
